import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { RetestResultVO, RetestResultForm, RetestResultQuery } from '@/api/qms/retestResult/types';

/**
 * 查询复测记录列表
 * @param query
 * @returns {*}
 */

export const listRetestResult = (query?: RetestResultQuery): AxiosPromise<RetestResultVO[]> => {
  return request({
    url: '/qms/retestResult/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询复测记录详细
 * @param batchCode
 */
export const getRetestResult = (batchCode: string | number): AxiosPromise<RetestResultVO> => {
  return request({
    url: '/qms/retestResult/' + batchCode,
    method: 'get'
  });
};

/**
 * 新增复测记录
 * @param data
 */
export const addRetestResult = (data: RetestResultForm) => {
  return request({
    url: '/qms/retestResult',
    method: 'post',
    data: data
  });
};

/**
 * 修改复测记录
 * @param data
 */
export const updateRetestResult = (data: RetestResultForm) => {
  return request({
    url: '/qms/retestResult',
    method: 'put',
    data: data
  });
};

/**
 * 删除复测记录
 * @param batchCode
 */
export const delRetestResult = (batchCode: string | number | Array<string | number>) => {
  return request({
    url: '/qms/retestResult/' + batchCode,
    method: 'delete'
  });
};
